Class: BuzzImage::Configuration
- Inherits:
-
Object
- Object
- BuzzImage::Configuration
- Defined in:
- lib/buzz_image/configuration.rb
Instance Attribute Summary collapse
-
#buzz_level ⇒ Object
Returns the value of attribute buzz_level.
-
#height ⇒ Object
Returns the value of attribute height.
-
#width ⇒ Object
Returns the value of attribute width.
Instance Method Summary collapse
-
#initialize ⇒ Configuration
constructor
A new instance of Configuration.
-
#set_options(&block) ⇒ Object
Override default options with the provided ones in block.
Constructor Details
#initialize ⇒ Configuration
Returns a new instance of Configuration.
5 6 7 8 9 |
# File 'lib/buzz_image/configuration.rb', line 5 def initialize @width = 90 @height = 90 @buzz_level = 1.5 end |
Instance Attribute Details
#buzz_level ⇒ Object
Returns the value of attribute buzz_level.
3 4 5 |
# File 'lib/buzz_image/configuration.rb', line 3 def buzz_level @buzz_level end |
#height ⇒ Object
Returns the value of attribute height.
3 4 5 |
# File 'lib/buzz_image/configuration.rb', line 3 def height @height end |
#width ⇒ Object
Returns the value of attribute width.
3 4 5 |
# File 'lib/buzz_image/configuration.rb', line 3 def width @width end |
Instance Method Details
#set_options(&block) ⇒ Object
Override default options with the provided ones in block
12 13 14 |
# File 'lib/buzz_image/configuration.rb', line 12 def (&block) block.yield(self) end |